@@ -150,12 +150,12 @@ def get_train_features(df, sensor='12', stage='pause', use_average = False):
         return data, sensors_to_use, stages_to_use
 
 
-def log_artifact(filepath):
-    print('fp: ', filepath)
-    with tempfile.TemporaryDirectory() as tmp:
-        path = os.path.join(tmp, filepath)
-        print('tp: ', path)
-        mlflow.log_artifact(path)        
+# def log_artifact(filepath):
+#     print('fp: ', filepath)
+#     with tempfile.TemporaryDirectory() as tmp:
+#         path = os.path.join(tmp, filepath)
+#         print('tp: ', path)
+#         mlflow.log_artifact(path)        
 
 def get_plots(model):
 
@@ -163,13 +163,13 @@ def get_plots(model):
 
     plot_model(model, plot = 'confusion_matrix', save=True)
     cm = os.path.join(os.getcwd(), 'Confusion Matrix.png')
-    # mlflow.log_artifact(cm)
-    log_artifact(cm)
+    mlflow.log_artifact(cm)
+    # log_artifact(cm)
 
     plot_model(model, plot = 'class_report', save=True) 
     cr = os.path.join(os.getcwd(), 'Class Report.png')
-    # mlflow.log_artifact(cr)  
-    log_artifact(cr)
+    mlflow.log_artifact(cr)  
+    # log_artifact(cr)
     
 
 
@@ -202,10 +202,11 @@ def specificity(actual, pred, pos_label=0):
 
 def objective(trial, df, study_name, stage, sensor, use_average, model_mode, suggest):
 
-    # mlflow.set_experiment('raptor_experiment')
+        # mlflow.set_experiment('raptor_exp')
 
         # artifact_path = mlflow.get_artifact_uri()
 
+        mlflow.start_run(nested=True)
     # with mlflow.start_run():
         if suggest:
             stage = trial.suggest_categorical("stages", ["pause", "all", 'random'])
@@ -217,8 +218,8 @@ def objective(trial, df, study_name, stage, sensor, use_average, model_mode, sug
         data, sensors_to_use, stages_to_use = get_train_features(df, sensor=sensor, stage=stage, use_average=use_average)
 
 
-        clf = setup(data, target = 'result', silent=True, log_experiment=True, log_plots=True, experiment_name=study_name, preprocess=False)
-        
+        clf = setup(data, target = 'result', silent=True, log_plots=True, experiment_name=study_name, preprocess=False)
+                                                                    # log_experiment=True,
         add_metric('specificity', 'Specificity', specificity)
         remove_metric('MCC')
         remove_metric('Kappa')
@@ -240,12 +241,6 @@ def objective(trial, df, study_name, stage, sensor, use_average, model_mode, sug
             metrics = dict(zip(keys, values))
 
 
-            # metrics = pull().sort_values(by=['Accuracy', 'Recall']).reset_index()
-            # metrics = metrics[metrics['Fold']=='Mean'].iloc[:,-6:]
-            # keys = metrics.columns
-            # values = metrics.values[0]
-            # metrics = dict(zip(keys, values))
-
             get_plots(model)
             mlflow.sklearn.log_model(model, artifact_path=model_name)
            
@@ -259,14 +254,6 @@ def objective(trial, df, study_name, stage, sensor, use_average, model_mode, sug
             metrics = dict(zip(keys, values))
             
 
-
-
-            # metrics = pull().sort_values(by=['Accuracy', 'Recall']).reset_index()#.loc[('CV-Val', 'Mean')]
-            # metrics = metrics[metrics['Fold']=='Mean'].iloc[:,-6:]
-            # keys = metrics.columns
-            # values = metrics.values[0]
-            # metrics = dict(zip(keys, values))
-
             get_plots(model)
             mlflow.sklearn.log_model(model, artifact_path=model_name)
                     
@@ -281,10 +268,6 @@ def objective(trial, df, study_name, stage, sensor, use_average, model_mode, sug
             values = metrics.values[0]
             metrics = dict(zip(keys, values))
 
-            # model_id = pull().sort_values(by=['Accuracy', 'Recall', 'Specificity'], ascending=False).iloc[0][0]
-            # model_name = MODELS[model_id]
-
-            # metrics = pull().sort_values(by=['Accuracy', 'Recall']).iloc[0][1:-1]    
 
             get_plots(model)
             mlflow.sklearn.log_model(model, artifact_path=model_name)
@@ -311,7 +294,7 @@ def objective(trial, df, study_name, stage, sensor, use_average, model_mode, sug
         mlflow.set_tag('model_mode', model_mode)
         mlflow.set_tag('suggest', suggest)
 
-
+        mlflow.end_run()
         print('Click on this link to track experiments: ', mlflow.get_tracking_uri())
 
 
@@ -319,7 +302,7 @@ def objective(trial, df, study_name, stage, sensor, use_average, model_mode, sug
 
 
 
-def train_experiments(df, study_name='raptor', direction='maximize', stage='pause', sensor='12', use_average=False, model_mode='random', n_trials=5, suggest=False, remote_tracking=False):
+def train_experiments(df, study_name='raptor', direction='maximize', stage='pause', sensor='12', use_average=False, model_mode='random', n_trials=5, suggest=False, remote_tracking=True):
     """trains several models during different trials and logs them. Experiemnt can be tracked on "http://ec2-3-10-175-206.eu-west-2.compute.amazonaws.com:5000/"
 
 
